<?php
//Script Creado por Carlos www.meteoviso.es
// Rutas de archivos
$RAINHIDRO = '/var/www/html/script/rainhidrototal.txt';
$directory = '/var/www/html/Reports/';
$START_YEAR = 2021;  // Variable para definir el año de inicio

// Obtener el año y mes actuales
$currentYear = date("Y");
$currentMonth = date("n");

// Configuración de fecha para pruebas
//$currentYear = "2023";
//$currentMonth = "9";

// Determinar el año hidrológico
$hydrologicalYear = $currentMonth >= 10 ? $currentYear : $currentYear - 1;

// Función para obtener el valor de precipitación de un mes específico
function getPrecipitationValue($year, $month, $directory) {
    $filename = $directory . 'NOAAYR' . $year . '.txt';
    if (!file_exists($filename)) {
        return null;
    }
    $content = file_get_contents($filename);
    
    // Extraer la sección de precipitaciones
    $pattern = '/Precipitation \(mm\)(.*?)Wind Speed \(km\/h\)/s';
    if (preg_match($pattern, $content, $matches)) {
        $precipitationSection = $matches[1];
        
        // Buscar el valor de precipitación para el mes específico
        $monthPattern = '/\b' . substr($year, -2) . '\s+' . str_pad($month, 2, ' ', STR_PAD_LEFT) . '\s+(\d+,\d+|\d+\.\d+)/';
        if (preg_match($monthPattern, $precipitationSection, $monthMatches)) {
            return str_replace(',', '.', $monthMatches[1]);
        }
    }
    
    return null;
}

// Array para almacenar los valores de precipitación
$precipitationValues = [];

// Leer los valores de octubre a septiembre
echo "Valores de precipitación del año hidrológico $hydrologicalYear-" . ($hydrologicalYear + 1) . ":<br><br>";
$total = 0;
for ($i = 0; $i < 12; $i++) {
    $month = $i + 10 > 12 ? $i - 2 : $i + 10;
    $year = $month < 10 ? $hydrologicalYear + 1 : $hydrologicalYear;
    
    $monthName = date("M", mktime(0, 0, 0, $month, 1));
    
    echo str_pad($monthName, 10);
    echo str_pad($year, 10);
    if ($year == $currentYear && $month == $currentMonth) {
        echo str_pad("0.00 mm", 15, " ", STR_PAD_LEFT);
    } elseif (($year > $currentYear) || ($year == $currentYear && $month > $currentMonth)) {
        echo str_pad("N/A", 15, " ", STR_PAD_LEFT);
    } else {
        $value = getPrecipitationValue($year, $month, $directory);
        if ($value !== null) {
            echo str_pad($value . " mm", 15, " ", STR_PAD_LEFT);
            $total += floatval($value);
        } else {
            echo str_pad("N/A", 15, " ", STR_PAD_LEFT);
        }
    }
    echo "<br>";
}
echo "<br>";
echo str_pad("Total anual:", 20);
echo str_pad(number_format($total, 2) . " mm", 15, " ", STR_PAD_LEFT);
echo "<br>";

// Actualizar el archivo RAINHIDRO con el total anual
file_put_contents($RAINHIDRO, $total);

echo "<br>Datos actualizados y guardados.<br>";

// Función para calcular el total de un año hidrológico específico
function calculateHydrologicalYearTotal($hydroYear, $directory) {
    $total = 0;
    for ($i = 0; $i < 12; $i++) {
        $month = $i + 10 > 12 ? $i - 2 : $i + 10;
        $year = $month < 10 ? $hydroYear + 1 : $hydroYear;
        
        // Si estamos en el año actual, solo sumamos hasta el mes actual
        if ($year > date("Y") || ($year == date("Y") && $month > date("n"))) {
            continue;
        }
        
        $value = getPrecipitationValue($year, $month, $directory);
        if ($value !== null) {
            $total += floatval($value);
        }
    }
    return $total;
}

// Mostrar tabla histórica
echo "<br><h3 style='text-align: center; color: #333; font-family: Arial, sans-serif;'>Histórico de Precipitaciones por Año Hidrológico</h3>";
echo "<table style='
    width: 100%; 
    max-width: 600px; 
    margin: 0 auto; 
    border-collapse: collapse; 
    font-family: Arial, sans-serif;
    
    box-shadow: 0 2px 5px rgba(0,0,0,0.1);
'>";
echo "<tr style='background-color: #4CAF50; color: white;'>
        <th style='padding: 10px; font-size: 50px; border: 1px solid #ddd;'>Año Hidrológico</th>
        <th style='padding: 10px; font-size: 50px; border: 1px solid #ddd;'>Total</th>
      </tr>";

// Mostrar datos desde START_YEAR hasta el año actual
for ($year = $START_YEAR; $year <= $currentYear; $year++) {
    $yearTotal = calculateHydrologicalYearTotal($year, $directory);
    
    // Estilo condicional para el año actual
    if ($year == $hydrologicalYear) {
        echo "<tr style='background-color: #f0f0f0; font-weight: bold;'>";
        echo "<td style='padding: 8px; border: 1px solid #ddd; text-align: center; font-size: 50px;'>$year-" . ($year + 1) . " (Actual)</td>";
        
        echo "<td style='padding: 8px; border: 1px solid #ddd; text-align: right; white-space: nowrap; font-size: 50px;'>" . number_format($yearTotal, 2) . " mm</td>";
        echo "</tr>";
    } else {
        // Alternar colores de fondo para mejorar legibilidad
        $bgColor = ($year % 2 == 0) ? '#ffffff' : '#f9f9f9';
        echo "<tr style='background-color: $bgColor;'>";
        echo "<td style='padding: 8px; border: 1px solid #ddd; text-align: center;font-size: 50px;'>$year-" . ($year + 1) . "</td>";
        echo "<td style='padding: 8px; border: 1px solid #ddd; text-align: right; font-size: 50px;'>" . number_format($yearTotal, 2) . " mm</td>";
        echo "</tr>";
    }
}

echo "</table>";
?>